#########
Changelog
#########

Version 0.0.3
=============

- Repair some bugs.
- Add an option for building constraints common for all assets classes.


Version 0.0.2
=============

- Repair some bugs.


Version 0.0.1
=============

- Implement robust estimates and ewma estimates.
- Implement Black Litterman model and risk factors models.
- Implement mean risk optimization with 10 risk measures.
